@@ -59,7 +59,7 @@ else:
             if opt._long_opts[0][2:] in option_blacklist: 
                 continue
             long_name = opt._long_opts[0][2:]
-            if opt.action != 'store_true':
+            if opt.action not in ('store_true', 'store_false'):
                 long_name = long_name + "="
             short_name = None
             if opt._short_opts:
@@ -76,7 +76,10 @@ else:
         user_options = get_user_options(__parser)
 
         def initialize_options(self):
-            """create the member variables, but change hyphens to underscores"""
+            """create the member variables, but change hyphens to
+            underscores
+            """
+            
             self.option_to_cmds = {}
             for opt in self.__parser.option_list:
                 cmd_name = opt._long_opts[0][2:]
@@ -102,7 +105,7 @@ else:
                 self.distribution.fetch_build_eggs(
                     self.distribution.tests_require)
 
-            argv = [] 
+            argv = ['nosetests'] 
             for (option_name, cmd_name) in self.option_to_cmds.items():
                 if option_name in option_blacklist:
                     continue
