@@ -457,10 +457,15 @@ def all_config_files():
 # used when parsing config files
 def flag(val):
     """Does the value look like an on/off flag?"""
+    if val == 1:
+        return True
+    elif val == 0:
+        return False
+    val = str(val)
     if len(val) > 5:
         return False
     return val.upper() in ('1', '0', 'F', 'T', 'TRUE', 'FALSE', 'ON', 'OFF')
 
 
 def _bool(val):
-    return val.upper() in ('1', 'T', 'TRUE', 'ON')
+    return str(val).upper() in ('1', 'T', 'TRUE', 'ON')
